#!/bin/bash
##
# Himp MacOS
# @version 4.6.1
# @license GPLv3: https://gnu.org/licenses/gpl.html
#
# Himp installation script for Mac
################################################################################
error=0
cur_dir=$(dirname "$PWD/$0")
install_for_this_user="0"
# x86_64 | arm64
arch="arm64"


function doFiles {
  mkdir /Applications/Himp
  exit_code=$?
  if [ $exit_code == 1 ]; then
    printf "  Cannot create folder in /Applications.\n"
    printf "  Trying in user\'s home\n"
    fichier_app="$HOME/Himp"
    mkdir $fichier_app
    error=$[$error + $?]
  else
    fichier_app="/Applications/Himp"
  fi


  cd "$cur_dir"
  cp ./Himp.jar "$fichier_app/"
  cp ./himpctl.sh "$fichier_app/"
  mkdir "$fichier_app/jre"
  if [ "$arch" == "arm64" ]; then
    tar -x -f "./jre-arm64.tar.gz" -C "$fichier_app/jre" --strip-components 1
  else
    tar -x -f "./jre.tar.gz" -C "$fichier_app/jre" --strip-components 1
  fi
  error=$[$error + $?]

  # Start script
  printf "#!/bin/bash\ncd $fichier_app\n./jre/Contents/Home/bin/java -jar $fichier_app/Himp.jar\n" > $fichier_app/himp.sh

  # Debug script
  printf "#!/bin/bash\ncd $fichier_app\n./jre/Contents/Home/bin/java -jar $fichier_app/Himp.jar -d\n" > $fichier_app/debug.sh


  error=$[$error + $?]
  chmod 755 $fichier_app/himp.sh
  chmod 755 $fichier_app/debug.sh
  error=$[$error + $?]
  cp "$cur_dir/uninstall.sh" $fichier_app/
  cp "$cur_dir/setup_printers.sh" $fichier_app/
}


if [ -d "/Applications/Himp" ]; then
  printf "  Another installation found, do you want to:
  1. Reinstall
  2. Install for this user
  3. Abort
"
  while true; do
    read -p "  Option: " ANSWER
    case $ANSWER in
      "1")
        "$cur_dir"/uninstall.sh -q
        if [ "$?" != "0" ]; then
          printf "  Error: cannot uninstall. Use your admin account or sudo\n"
          exit 1
        fi
        doFiles
        break
        ;;
      "2")
        fichier_app="/Applications/Himp"
        install_for_this_user="1"
        break
        ;;
      "3")
        printf "  Exiting\n"
        exit 0
        break
        ;;
      *)
        printf " !! Please insert '1', '2' or '3'\n"
    esac
  done
elif [ -d "$HOME/Himp" ]; then
  printf "  Another installation found, do you want to reinstall? (Y/n)\n"
  while true; do
    read -p "  Option: " ANSWER
    case $ANSWER in
      ""|"Y"|"y"|"yes"|"Yes"|"YES")
        "$cur_dir"/uninstall.sh -q
        if [ "$?" != "0" ]; then
          printf "  Error: cannot uninstall. Use your admin account or sudo\n"
          exit 1
        fi
        doFiles
        break
        ;;
      *)
        printf "  Exiting\n"
        exit 0
        break
        ;;
    esac
  done
else
  doFiles
fi




startup="<?xml version=\"1.0\" encoding=\"UTF-8\"?>
<!DOCTYPE plist PUBLIC \"-//Apple Computer//DTD PLIST 1.0//EN\" \"http://www.apple.com/DTDs/PropertyList-1.0.dtd\">
<plist version=\"1.0\">
<dict>
   <key>Label</key>
   <string>com.hiboutik.himp</string>
   <key>Program</key>
   <string>$fichier_app/himp.sh</string>
   <key>RunAtLoad</key>
   <true/>
</dict>
</plist>"

if [ ! -d "$HOME/Library/LaunchAgents" ]; then
  printf "  creating \"LaunchAgents\" folder...\n"
  mkdir "$HOME/Library/LaunchAgents"
  error=$[$error + $?]
fi


printf "$startup" > "$HOME/Library/LaunchAgents/com.hiboutik.himp.plist"
error=$[$error + $?]
if [ $error != 0 ]; then
  printf "  error $error\n"
fi
if [ $error == 0 ]; then
  launchctl load "$HOME/Library/LaunchAgents/com.hiboutik.himp.plist"
  launchctl start com.hiboutik.himp
  printf "  installed successfuly!\n"
  if [ $install_for_this_user == "0" ]; then
    while true; do
      read -p "Do you wish to configure local printers (e.g. USB)? (Y/n)" ANSWER
      case $ANSWER in
        ""|"Y"|"y"|"yes"|"Yes"|"YES")
          ./setup_printers.sh $fichier_app
          break
          ;;
        "n"|"N"|"no"|"No"|"NO")
          printf "> Cancelled\n"
          break
          ;;
        *)
              printf " !! Please insert 'y' or 'n'\n"
      esac
    done
  fi
else
  printf "  Errors during installation\n"
  printf Cleanup? \(Y/n\)
  read -t 10 REPONSE
  if [ "$REPONSE" == "y" ] || [ "$REPONSE" == "" ] || [ "$REPONSE" == "Y" ]; then
    sh $cur_dir/uninstall.sh
  elif [ "$REPONSE" == "n" ]; then
    printf exiting...
  else
    printf Invalid option, exiting...
    exit 2
  fi
fi

exit 0
