#!/bin/bash
##
# Himp MacOS
# @version 4.6.1
# @license GPLv3: https://gnu.org/licenses/gpl.html
#
# This script generates a configuration file for Himp
################################################################################


#### Check destination
destination="$1"
if [ "$destination" == "" ]; then
    if [ -d "/Applications/Himp" ] && [ -w "/Applications/Himp" ]; then
        destination="/Applications/Himp"
    elif [ -d "$HOME/Himp" ]; then
        destination="$HOME/Himp"
    else
        printf "> Error: cannot write config file\n"
        exit 1
    fi
fi
config_file="himp.conf"


#### Show printer select menu
printers[0]="none"
printers[1]="default"
printf "0 None\n"
printf "1 Default\n"
c=1
for printer in $(lpstat -a|cut -d' ' -f1); do
  c=$(($c + 1))
  printers[$c]=$printer
  printf "$c $printer\n"
done
printf "\n"


function writeConfigFile {
  printf "> Writing configuration to $config_file..."
  file="$destination/$config_file"
  touch "$file"
  cat /dev/null > "$file"
  pt=${set_printers[0]}
  printf "ticketPrinter="${printers[$pt]}"\n" >> $file
  pl=${set_printers[1]}
  printf "labelPrinter="${printers[$pl]}"\n" >> $file
  pd=${set_printers[2]}
  printf "pdfPrinter="${printers[$pd]} >> $file
  printf " Done!\n"
}


function choosePrinter {
  while true; do
    read -p "Choose your $1 printer please: " ANSWER
    case $ANSWER in
      [0-$2])
        set_printers[$3]=$ANSWER
        printf "> You chose "${printers[$ANSWER]}"\n\n"
        break
        ;;
      *)
        printf " !! This printer does not exist\n"
    esac
  done
}


function restartProcess {
    printf "> Stopping Himp..."
    launchctl stop com.hiboutik.himp
    if [ "$?" == 0 ]; then
        printf " OK!\n"
        sleep 1
        printf "> Restarting Himp..."
        launchctl start com.hiboutik.himp
        if [ "$?" == 0 ]; then
            printf " OK!\n"
        else
            printf "> Error starting Himp. Try reinstalling."
        fi
    fi
}


choosePrinter TICKET $c 0
choosePrinter LABEL $c 1
# choosePrinter PDF $c 2


while true; do
  read -p "Write this configuration to file? (Y/n)" ANSWER
  case $ANSWER in
    ""|"Y"|"y"|"yes"|"Yes"|"YES")
      writeConfigFile
      restartProcess
      break
      ;;
    "n"|"N"|"no"|"No"|"NO")
      printf "> Cancelled\n"
      break
      ;;
    *)
      printf " !! Please insert 'y' or 'n'\n"
  esac
done


exit 0
