#!/bin/bash
##
# Himp MacOS
# @version 4.6.1
# @license GPLv3: https://gnu.org/licenses/gpl.html
#
# Himp uninstallation script for Mac
################################################################################

opt1=$1
exit_code=0
declare -r LABEL="com.hiboutik.himp"

daemon_loaded=0
daemon_installed=0
main_directory=0


function log {
  if [ "$opt1" != "-q" ]; then
    printf "    $1\n"
  fi
}


# Is the daemon loaded?
launchctl list $LABEL > /dev/null 2>&1
if [ "$?" = "0"  ]; then
  daemon_loaded=1
fi

# Does the plist file exists?
if [ -f "/Users/$USER/Library/LaunchAgents/$LABEL.plist" ]; then
  daemon_installed=1
fi

# The installation directory exists?
if [ -d "/Applications/Himp" ]; then
  main_directory="/Applications/Himp"
elif [ -d "/Users/$USER/Himp" ]; then
  main_directory="/Users/$USER/Himp"
fi


if [ "$daemon_loaded" == "0" ] && [ "$daemon_installed" == "0" ] && [ "$main_directory" == "0" ]; then
  log "Nothing to uninstall"
  exit 0
fi


log "Starting Himp uninstallation"

# Start file operations
if [ "$daemon_loaded" != "0" ]; then
  log "Unloading daemon..."
  launchctl stop $LABEL
  launch_unload=$(launchctl unload /Users/$USER/Library/LaunchAgents/$LABEL.plist > /dev/null 2>&1)
  if [ $? == "0" ]; then
    log "unloaded"
  else
    log "error unloading service"
    exit_code=$(($exit_code + 1))
  fi
else
  log "Daemon not loaded"
fi


if [ "$daemon_installed" != "0" ]; then
  rm /Users/$USER/Library/LaunchAgents/$LABEL.plist
  if [ $? == "0" ]; then
    log "removed from LaunchAgents"
  else
    log "error removing from LaunchAgents"
    exit_code=$(($exit_code + 2))
  fi
else
  log "Not found in LaunchAgents"
fi


if [ "$main_directory" != "0" ]; then
  cd "$main_directory/../"
  rm -Rf "$main_directory" > /dev/null 2>&1
  if [ $? == "0" ]; then
    log "removed from $main_directory"
  else
    log "Cannot remove from $main_directory. Use your admin account or sudo."
    exit_code=$(($exit_code + 8))
  fi
else
  log "The Himp was not found!"
  exit_code=$(($exit_code + 16))
fi




if [ "$exit_code" != "0" ]; then
  log "Errors were encountered!"
else
  log "Done!"
fi

exit $exit_code
